# v0.0.4
- Fix some non-async calls

# v0.0.3
- Async Query of Mistral API

# v0.0.2
- More lax python version for HuggingFace Space

# v0.0.1
- Prototype with two agents with tool calling, handoff, streaming of answer and state. 